#
# spec file for package python-jupyter_nbdime
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%{?!python_module:%define python_module() python-%{**} python3-%{**}}
Name:           python-jupyter_nbdime
Version:        1.0.2
%define labver  0.4.0
Release:        2.17
Summary:        Tools for diffing and merging Jupyter Notebooks
License:        BSD-3-Clause
Group:          Development/Languages/Python
Url:            https://github.com/jupyter/nbdime
Source:         https://files.pythonhosted.org/packages/py2.py3/n/nbdime/nbdime-%{version}-py2.py3-none-any.whl
BuildRequires:  %{python_module GitPython >= 2.1.6}
BuildRequires:  %{python_module colorama}
BuildRequires:  %{python_module devel}
BuildRequires:  %{python_module Jinja2 >= 2.9}
BuildRequires:  %{python_module jupyter_nbformat}
BuildRequires:  %{python_module jupyter_notebook}
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module requests}
BuildRequires:  %{python_module six}
BuildRequires:  %{python_module tornado}
BuildRequires:  fdupes
BuildRequires:  python-backports.functools_lru_cache
BuildRequires:  python-backports.shutil_which
BuildRequires:  python-rpm-macros
BuildRequires:  zip
BuildRequires:  unzip
Requires:       python-GitPython >= 2.1.6
Requires:       python-Jinja2 >= 2.9
Requires:       python-colorama
Requires:       python-jupyter_nbformat
Requires:       python-jupyter_notebook
Requires:       python-requests
Requires:       python-six
Requires:       python-tornado
Recommends:     python-tabulate
%ifpython2
Requires:       python-backports.functools_lru_cache
Requires:       python-backports.shutil_which
Requires:       python3-jupyter_nbdime
%endif
BuildArch:      noarch

%python_subpackages

%description
The nbdime package provides tools for diffing and merging of
Jupyter Notebooks.

 * nbdiff compare notebooks in a terminal-friendly way
 * nbmerge three-way merge of notebooks with automatic conflict resolution
 * nbdiff-web shows you a rich rendered diff of notebooks
 * nbmerge-web gives you a web-based three-way merge tool for notebooks
 * nbshow present a single notebook in a terminal-friendly way

%package git
Summary:        Git integration for %{name}
Group:          Development/Languages/Python
Requires:       %{name} = %{version}
Requires:       git

%description git
This package provides git integration for %{name}

%package hg
Summary:        Mercurial integration for %{name}
Group:          Development/Languages/Python
Requires:       %{name} = %{version}
Requires:       mercurial

%description hg
This package provides mercurial integration for %{name}

%prep
%setup -c -T
unzip %{SOURCE0} 'nbdime/*'
find nbdime/ -type f -name "*.py" -exec sed -i 's/\r$//' {} +
find nbdime/ -type f -name "*.py" -exec sed -i -e '/^#!\//, 1d' {} +
zip -r %{SOURCE0} nbdime
rm -rf nbdime

%build
# Not needed

%install
%python_expand pip%{$python_bin_suffix} install --root=%{buildroot} %{SOURCE0}
%python_expand %fdupes %{buildroot}%{$python_sitelib}

if [ $(dirname %{_prefix}/etc/jupyter) != $(dirname %{_sysconfdir}/jupyter) ]; then
mkdir -p %{buildroot}%{_sysconfdir}
mv %{buildroot}%{_prefix}/etc/jupyter %{buildroot}%{_sysconfdir}/jupyter
rm -d %{buildroot}%{_prefix}/etc
fi

%{fdupes %{buildroot}%{_datadir}/jupyter/ %{buildroot}%{python3_sitelib}}

cp %{buildroot}%{python_sitelib}/nbdime-%{version}.dist-info/LICENSE.txt .

%files %{python_files}
%python3_only %{_bindir}/nbdime
%python3_only %{_bindir}/nbshow
%python3_only %{_bindir}/nbdiff
%python3_only %{_bindir}/nbdiff-web
%python3_only %{_bindir}/nbmerge
%python3_only %{_bindir}/nbmerge-web
%python3_only %dir %{_datadir}/jupyter/lab/
%python3_only %dir %{_datadir}/jupyter/lab/extensions/
%python3_only %{_datadir}/jupyter/lab/extensions/nbdime-jupyterlab-%{labver}.tgz
%python3_only %{_datadir}/jupyter/nbextensions/nbdime/
%python3_only %config %{_sysconfdir}/jupyter/jupyter_notebook_config.d/nbdime.json
%python3_only %config %{_sysconfdir}/jupyter/nbconfig/notebook.d/nbdime.json
%{python_sitelib}/nbdime/
%{python_sitelib}/nbdime-%{version}.dist-info/
%license %{python_sitelib}/nbdime-%{version}.dist-info/LICENSE.txt
%exclude %{python_sitelib}/nbdime/vcs/git/
%exclude %{python_sitelib}/nbdime/vcs/hg/

%files %{python_files git}
%license LICENSE.txt
%python3_only %{_bindir}/git-nbdiffdriver
%python3_only %{_bindir}/git-nbdifftool
%python3_only %{_bindir}/git-nbmergedriver
%python3_only %{_bindir}/git-nbmergetool
%{python_sitelib}/nbdime/vcs/git/

%files %{python_files hg}
%license LICENSE.txt
%python3_only %{_bindir}/hg-nbdiff
%python3_only %{_bindir}/hg-nbdiffweb
%python3_only %{_bindir}/hg-nbmerge
%python3_only %{_bindir}/hg-nbmergeweb
%{python_sitelib}/nbdime/vcs/hg/

%changelog
* Thu Aug  2 2018 toddrme2178@gmail.com
- Update to version 1.0.2
  * Diff: Optimized diffing of large texts (e.g. big cells).
  * Config: Fixed several issues with the config system.
  * Lab extension: Updated to latest jupyterlab. All npm packages are now using ES6 features.
  * Web: Fixed keyboard tabbing / focusing issues.
- Update to version 1.0.1
  * Web: Fix output rendering of outputs with a period in MIME type name.
  * Config: Add configuration option for front-end extensions.
  * Merging: Fix handling of corner case for inline merge strategy.
  * Various other fixes and adjustments.
* Sun Jun 10 2018 jengelh@inai.de
- Use find "+" strategy.
- Use noun phrase in summary.
* Fri May 18 2018 toddrme2178@gmail.com
- Update to version 1.0.0
  * Added ability for git diff driver to integrate with git filters.
  * Improved/fixed merge resolution for similar cell insertions.
  * Added config system to allow for configuring the various entrypoints. Especially useful for customizing which keys to ignore when diffing.
  * Added control to web view of outputs to select which MIME type to render, and to enable trusting of outputs for full rendering.
  * Added jupyterlab extension. Frontend/server extensions are now enabled by default on installation.
  * Various fixes and adjustments.
- Switch to wheel-based install
* Fri May 18 2018 tchvatal@suse.com
- Remove python3-jupyter_vega3 requires as we never had this pkg
  present in the d:l:py, it is not mentioned in the setup.py
- Run the tests
* Fri Apr 20 2018 toddrme2178@gmail.com
- Initial version
